@@ -1,63 +1,22 @@
 import requests
 import urllib3
 import time
-import functools
 import logging
-import traceback
-import inspect
-from typing import Callable, Any
 from typing import List, Dict, Any, Optional
 
 log=logging.getLogger(__name__)
+log.setLevel(logging.WARNING)
+formatter = logging.Formatter(
+    fmt="%(asctime)s | %(levelname)s | %(name)s | %(filename)s:%(lineno)d | %(message)s",
+    datefmt="%Y-%m-%d %H:%M:%S"
+)
+console_handler = logging.StreamHandler()
+console_handler.setFormatter(formatter)
+log.addHandler(console_handler)
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 
-def enter_and_leave_function(func: Callable) -> Callable:
-    """
-    函数调用日志装饰器：
-    1. 记录函数入参、调用位置
-    2. 正常执行时记录返回值
-    3. 异常时记录完整堆栈（含函数内具体报错行数）
-    """
-
-    @functools.wraps(func)  # 保留原函数元信息（如 __name__、__doc__）
-    def wrapper(*args: Any, **kwargs: Any) -> Any:
-        # 获取函数定义的文件路径和行号（基础位置信息）
-        func_def_file = inspect.getsourcefile(func) or "unknown_file"
-        func_def_file = func_def_file.split("/")[-1]
-        func_def_line = inspect.getsourcelines(func)[1] if func_def_file != "unknown_file" else "unknown_line"
-        log.info(
-            f"[{func_def_file}: {func_def_line}]"
-            f"[{func.__name__}()]"
-            f"| args={args}, kwargs={kwargs}"
-        )
-
-        try:
-            result = func(*args, **kwargs)
-            log.info(
-                f"[{func_def_file}: {func_def_line}]"
-                f" finish run function {func.__name__}(), return value is: {result} "
-            )
-            return result
-
-        except Exception as e:
-            error_traceback = traceback.format_exc()
-
-            log.error(
-                f"[{func_def_file}: {func_def_line}]"
-                f"failed to run function {func.__name__}() :Failed. "
-                f"| error_type：{type(e).__name__} "
-                f"| error_message：{str(e)} "
-                f"| full_stack_trace：\n{error_traceback}",
-                exc_info=False  # 已手动捕获堆栈，避免 logging 重复打印
-            )
-            raise  # 重新抛出异常，不中断原异常链路
-
-    return wrapper
-
-
-
 class CloudPods:
     def __init__(self,keystone_url,username,password,domain="default",project="system"):
         self.__keystone_url = keystone_url
@@ -120,126 +79,111 @@ class CloudPods:
         try:
             rs = session.post(url=url, json=data, verify=False, timeout=600)
             if rs.status_code != 200:
-                log.error(f"Failed to get /auth/tokens: Error. err msg is {str(rs.text)}")
+                log.warning(f"获取token失败，url: {url},request data:{data},状态码为 {rs.status_code}，返回信息为{rs.text}")
                 return None
             if "X-Subject-Token" not in rs.headers.keys():
-                log.error(f"Failed to get /auth/tokens for X-Subject-Token not in rs.headers.keys(): Error. err msg is {str(rs.text)}")
+                log.warning(f"获取token失败，url: {url},request data:{data},返回header中没有X-Subject-Token字段，headers为{rs.headers}")
                 return None
             token = rs.headers["X-Subject-Token"]
             if not token:
-                log.error(f"Failed to get /auth/tokens for token is None: Error. err msg is {str(rs.text)}")
+                log.warning(f"获取token失败，url: {url},request data:{data},headers:{rs.headers},token为空")
                 return None
-            log.info(f"Get /auth/tokens success. token is {token}")
+            log.info(f"Get session success: OK. token is {token}")
             headers['X-Auth-Token'] = token
             session.headers.update(headers)
-            log.info(f"Get session success: OK.")
+            log.info(f"Get session success: OK. session is {session}")
             return session
         except Exception as e:
-            log.error(f"Failed to get /auth/tokens: Error. err msg is {str(e)}", exc_info=True)
+            log.error(f"获取token失败，url: {url},request data:{data},错误信息为{e}")
             return None
 
-    @enter_and_leave_function
     def __get_endpoint(self):
+        log.info(f"begin to get endpoint ...")
         try:
             get_endpoints_url = "/endpoints"
             url = self.__keystone_url + get_endpoints_url
             rs = self.__session.get(url=url, verify=False, timeout=600)
             if rs.status_code != 200:
-                log.error(f"Failed to get /endpoints: Error. err msg is {str(rs.text)}")
+                log.warning(f"获取endpoint 失败，返回码为 {rs.status_code}，返回信息为{rs.text}")
                 return None
             try:
                 rs_data = rs.json()
             except Exception as e:
-                log.error(f"Failed to get /endpoints: Error. err msg is {str(e)}", exc_info=True)
+                log.warning(f"获取endpoint 失败，返回数据为非JSON格式，返回数据为{rs.text}")
                 return None
             endpoints=dict({})
             if not rs_data:
-                log.error(f"Failed to get /endpoints for rs_data is None: Error. rs.text is {str(rs.text)}")
+                log.warning(f"获取endpoint 失败，返回数据为空")
                 return None
             if "endpoints" not in rs_data.keys():
-                log.error(f"Failed to get /endpoints for endpoints not in rs_data.keys(): Error. rs.text is {str(rs.text)}")
+                log.warning(f"获取endpoint 失败，返回数据中没有endpoints字段")
                 return None
             for elem in rs_data["endpoints"]:
                 if not elem:
-                    log.error(f"Failed to get /endpoints for elem is None: Error. rs.text is {str(rs.text)}")
+                    log.warning(f"获取endpoint 失败，返回数据中存在空元素")
                     return None
                 if "service_name" not in elem.keys():
-                    log.error(f"Failed to get /endpoints for service_name not in elem.keys(): Error. rs.text is {str(rs.text)}")
+                    log.warning(f"获取endpoint 失败，返回数据中没有server_name 字段")
                     return None
                 if "url" not in elem.keys():
-                    log.error(f"Failed to get /endpoints for url not in elem.keys(): Error. rs.text is {str(rs.text)}")
+                    log.warning(f"获取endpoint 失败，返回数据中没有url字段")
                     return None
                 if elem["service_name"] not in endpoints.keys():
                     endpoints[elem["service_name"]]=elem["url"]
+            log.info(f"Get endpoint success: OK. endpoints is {endpoints}")
             return endpoints
         except Exception as e:
             log.error(f"Failed to get /endpoints: Error. err msg is {str(e)}", exc_info=True)
 
-    @enter_and_leave_function
     def __create_server(self, server: Dict[str, Any], count: int = 1) -> Optional[Dict[str, Any]]:
-        """
-        内部方法：向API发送请求创建服务器
-
-        参数:
-            server: 服务器配置字典，包含创建服务器所需的各项参数
-            count: 要创建的服务器数量，默认为1
-
-        返回:
-            成功时返回API响应的JSON数据（字典类型）
-            失败时返回None，并记录错误日志
-        """
+        log.info(f"begin to create server ...")
+        request_url = ""
+        request_data = dict({})
         try:
-            # 构建请求URL（基于基础计算服务URL）
             request_url = f"{self.__compute_url}/servers"
-
-            # 构建请求数据结构
             request_data = {
-                "count": count,  # 创建数量
-                "server": server  # 服务器配置详情
+                "count": count,
+                "server": server
             }
-
-            # 发送POST请求创建服务器
-            # 注意：verify=False会禁用SSL证书验证，生产环境需谨慎使用
             log.info(f"开始创建服务器,url is {request_url},request data is {request_data}...")
             response = self.__session.post(
                 url=request_url,
                 json=request_data,
-                verify=False,  # 禁用SSL验证（根据环境需求调整）
-                timeout=600  # 设置较长超时时间（10分钟），适应服务器创建耗时操作
+                verify=False,
+                timeout=600
             )
 
-            # 检查HTTP响应状态码
             if response.status_code != 200:
-                # 记录错误响应详情（状态码和响应内容）
                 log.error(
+                    f"url:{request_url},"
+                    f"request data:{request_data},"
                     f"服务器创建失败: HTTP状态码 {response.status_code}, "
-                    f"错误信息: {response.text[:500]}..."  # 限制日志长度
+                    f"错误信息: {response.text}..."  # 限制日志长度
                 )
                 return None
-
-            # 解析JSON响应数据
             try:
                 response_data = response.json()
-                log.debug(f"服务器创建请求成功，响应数据: {response_data}")
+                log.info(f"服务器创建请求成功，响应数据: {response_data}")
                 return response_data
 
             except ValueError as e:
-                # 处理JSON解析失败的情况
                 log.error(
+                    f"url:{request_url},"
+                    f"request data:{request_data},"
                     f"服务器创建成功但响应解析失败: {str(e)}, "
-                    f"原始响应内容: {response.text[:500]}..."
+                    f"原始响应内容: {response.text}..."
                 )
                 return None
 
         except Exception as e:
-            # 捕获所有其他异常（如网络错误、超时等）
-            log.error(f"服务器创建请求发生异常: {str(e)}", exc_info=True)
+            log.error(f"服务器创建请求发生异常: url:{request_url},request data:{request_data},{str(e)}", exc_info=True)
             return None
 
-    @enter_and_leave_function
     def modify_src_check(self, server_id, src_ip_check="on", src_mac_check="on"):
         log.info(f"Begin to request /servers/{server_id}/modify-src-check...")
         res_data = {}
+        modify_src_check_url= ""
+        data=dict({})
         try:
             modify_src_check_url = f"/servers/{server_id}/modify-src-check"
             data = {
@@ -253,12 +197,11 @@ class CloudPods:
             res_data = res.json()
             log.info(f"Success to request /servers/{server_id}/modify-src-check: OK. response data is {res_data}")
         except Exception as e:
-            log.error(f"Failed to request /servers/{server_id}/modify-src-check: Error. err msg is {str(e)}",
+            log.error(f"Failed to request /servers/{server_id}/modify-src-check: Error. modify_src_check_url:{modify_src_check_url},data:{data},err msg is {str(e)}",
                       exc_info=True)
         finally:
             return res_data
 
-    @enter_and_leave_function
     def create_server_by_guest_image(
             self,
             guest_image_id: str,
@@ -308,6 +251,7 @@ class CloudPods:
         返回:
             成功创建的服务器ID列表，失败时返回空列表
         """
+        log.info(f"Begin to create server by guest image...")
         # 转换网络列表为API要求的格式
         nets = [{"network": net} for net in nets_list]
 
@@ -382,7 +326,7 @@ class CloudPods:
         # 解析返回结果，提取服务器ID
         server_ids: List[str] = []
         if not create_result or not isinstance(create_result, dict):
-            log.warning(f"创建服务器失败，返回结果: {create_result}")
+            log.warning(f"创建服务器失败，server_config:{server_config},count:{count},返回结果: {create_result}")
             return server_ids
         if "server" in create_result.keys() and "id" in create_result["server"]:
             # 单服务器创建成功
@@ -402,12 +346,11 @@ class CloudPods:
                 server_ids.append(server_info["body"]["id"])
         else:
             # 未找到服务器ID，记录警告
-            log.warning(f"创建服务器失败，未获取到server_id，返回结果: {create_result}")
-
+            log.warning(f"创建服务器失败，未获取到server_id，server_config:{server_config},count:{count},返回结果: {create_result}")
         return server_ids
 
-    @enter_and_leave_function
     def get_server_detail(self, server_id):
+        log.info(f"Get server detail by server_id: {server_id}")
         try:
             url = self.__compute_url + f"/servers/{server_id}"
             rs = self.__session.get(url=url, verify=False, timeout=600)
@@ -424,8 +367,8 @@ class CloudPods:
             log.warning(f"Failed to request /servers/{server_id}: Error.\rerr msg is {str(e)}")
             return None
 
-    @enter_and_leave_function
     def restart_server(self,server_id):
+        log.info(f"Restart server by server_id: {server_id}")
         try:
             url = self.__compute_url + f"/servers/{server_id}/restart"
             payload={
@@ -441,8 +384,8 @@ class CloudPods:
             log.error(f"Failed to request /servers/{server_id}/restart: Error.\rerr msg is {str(e)}")
             return False
 
-    @enter_and_leave_function
     def get_server_status(self,server_id):
+        log.info(f"Get server status by server_id: {server_id}")
         try:
             url = self.__compute_url + f"/servers/{server_id}/status"
             rs = self.__session.get(url=url, verify=False, timeout=600)
@@ -459,8 +402,8 @@ class CloudPods:
             log.error(f"Failed to request /servers/{server_id}/status: Error.\rerr msg is {str(e)}")
             return None
 
-    @enter_and_leave_function
     def get_server_ip(self, server_id,network_id=""):
+        log.info(f"Get server ip by server_id: {server_id}")
         try:
             server = self.get_server_detail(server_id)
             if not server:
@@ -492,8 +435,8 @@ class CloudPods:
             log.error(f"Failed to get server ip: Error.\rerr msg is {str(e)}")
             return None
 
-    @enter_and_leave_function
     def wait_for_server_is_on(self, server_id,timeout=1800):
+        log.info(f"Wait for server {server_id} is online")
         time_cost=0
         running_status_count = 0
         while True:
@@ -537,8 +480,10 @@ class CloudPods:
                 log.warning(f"Failed to get server_detail: Error. server_detail is: {server_detail}")
                 return False
 
-    @enter_and_leave_function
     def host_has_baremetal_server(self, host_id):
+        log.info(f"Check host {host_id} has baremetal server")
+        url=""
+        payload=dict({})
         try:
             url=self.__compute_url+"/servers"
             payload = {
@@ -554,21 +499,21 @@ class CloudPods:
             try:
                 rs_data = rs.json()
                 if not rs_data:
-                    log.warning(f"Failed to get server_detail: Error. server_detail is: {rs_data}")
+                    log.warning(f"Failed to get server_detail: Error. url:{url},payload:{payload},server_detail is: {rs_data}")
                     return False
                 if "servers" not in rs_data.keys():
-                    log.warning(f"Failed to get server_detail: Error. server_detail is: {rs_data}")
+                    log.warning(f"Failed to get server_detail: Error. url:{url},payload:{payload},server_detail is: {rs_data}")
                     return False
                 return bool(rs_data["servers"])
             except Exception as e:
-                log.warning(f"Failed to get server_detail: Error. server_detail is: {str(e)}")
+                log.warning(f"Failed to get server_detail: Error. url:{url},payload:{payload},server_detail is: {str(e)}")
                 return False
         except Exception as e:
-            log.error(f"Failed to request /servers: Error.\rerr msg is {str(e)}",exc_info=True)
+            log.error(f"Failed to request /servers: Error.url:{url},payload:{payload}, err msg is {str(e)}",exc_info=True)
             return False
 
-    @enter_and_leave_function
     def get_can_deploy_server_host_num(self,os_arch,bios_mode):
+        log.info(f"Get can deploy server host num")
         hosts=[]
         for elem in self.get_baremetal_hosts():
             if "user:test_os_type" in elem["metadata"].keys() and elem["metadata"]["user:test_os_type"]==f"{os_arch.lower()}_{bios_mode.lower()}":
@@ -576,8 +521,10 @@ class CloudPods:
                     hosts.append(elem)
         return len(hosts)
 
-    @enter_and_leave_function
     def get_host_spec(self,host_id):
+        log.info(f"Get host {host_id} spec")
+        url=""
+        payload=dict({})
         try:
             url=self.__compute_url+"/hosts/"+host_id+"/spec"
             payload = {
@@ -592,10 +539,10 @@ class CloudPods:
                 rs_data = rs.json()
                 return rs_data
             except Exception as e:
-                log.warning(f"Failed to get host spec: Error. rs is {rs.text}.\rerr msg is {str(e)}",exc_info=True)
+                log.warning(f"Failed to get host spec: Error. url:{url},payload:{payload},rs is {rs.text}.err msg is {str(e)}",exc_info=True)
                 return None
         except Exception as e:
-            log.error(f"Failed to request /hosts/{host_id}/spec: Error.\rerr msg is {str(e)}",exc_info=True)
+            log.error(f"Failed to request /hosts/{host_id}/spec: Error.url:{url},payload:{payload},err msg is {str(e)}",exc_info=True)
             return None
 
     def get_baremetal_hosts(self,page_size=10):
@@ -608,6 +555,7 @@ class CloudPods:
             Returns:
                 list: 所有裸金属主机的完整数据列表（若失败返回空列表）
             """
+        log.info(f"Get baremetal hosts")
         all_hosts = []  # 存储所有页的结果
         page_num = 1  # 起始页码（从1开始，根据API实际规则调整）
         url = f"{self.__compute_url}/hosts"  # 接口URL
@@ -687,8 +635,10 @@ class CloudPods:
 
         return all_hosts
 
-    @enter_and_leave_function
     def get_baremetal_servers(self):
+        log.info(f"Get baremetal servers")
+        url= ""
+        payload=dict({})
         try:
             get_all_baremetal_servers = f"/servers"
             url = self.__compute_url + get_all_baremetal_servers
@@ -704,14 +654,14 @@ class CloudPods:
                 rs_data = rs.json()
                 return rs_data
             except Exception as e:
-                log.warning(f"Failed to get baremetal servers: Error. rs is {rs.text}.\rerr msg is {str(e)}",exc_info=True)
+                log.warning(f"Failed to get baremetal servers: Error. url:{url},payload:{payload},rs is {rs.text}.err msg is {str(e)}",exc_info=True)
                 return None
         except Exception as e:
-            log.error(f"Failed to request /servers: Error.\rerr msg is {str(e)}", exc_info=True)
+            log.error(f"Failed to request /servers: Error.url:{url},payload:{payload},err msg is {str(e)}", exc_info=True)
             return None
 
-    @enter_and_leave_function
     def wait_for_server_is_deleted(self,server_id):
+        log.info(f"wait for server {server_id} is deleted...")
         try:
             for i in range(360):
                 status = self.get_server_status(server_id)
@@ -724,14 +674,14 @@ class CloudPods:
                     log.info(f"try to delete server {server_id}...")
                     self.delete_server(server_id)
             else:
-                log.warning(f"Failed to wait for server {server_id} is deleted and half hour has been passed: Error.\nserver status is {status}")
+                log.warning(f"Failed to wait for server {server_id} is deleted and half hour has been passed: Error.server status is {status}")
                 return False
         except Exception as e:
-            log.error(f"Failed to wait for server {server_id} is deleted: Error.\rerr msg is {str(e)}",exc_info=True)
+            log.error(f"Failed to wait for server {server_id} is deleted: Error.err msg is {str(e)}")
             return False
 
-    @enter_and_leave_function
     def delete_server(self, server_id):
+        log.info(f"try to delete server {server_id}...")
         try:
             delete_server_url = f"/servers/{server_id}"
             url = self.__compute_url + delete_server_url
@@ -740,9 +690,10 @@ class CloudPods:
             }
             rs = self.__session.delete(url=url,params=params, verify=False, timeout=600)
             if rs.status_code == 200:
+                log.info(f"server {server_id} has been deleted")
                 return True
             else:
-                log.error(f"Failed to delete server {server_id}: Error.\nresponse msg is {rs.text}")
+                log.error(f"Failed to delete server {server_id}: Error.status_code is {rs.status_code},response msg is {rs.text}")
                 return False
         except Exception as e:
             log.error(f"Failed to delete server {server_id}: Error.\nerr msg is {str(e)}",exc_info=True)
@@ -750,9 +701,9 @@ class CloudPods:
 
 
 if __name__ == '__main__':
-    cloudpods = CloudPods('https://10.30.18.1:30500/v3','admin','jSj@2008')
-    ip=cloudpods.get_server_ip("94914d36-2586-4eb3-8c91-0aac5c25e609")
-    print(ip)
+    # cloudpods = CloudPods('https://10.30.18.1:30500/v3','admin','jSj@2008')
+    # ip=cloudpods.get_server_ip("94914d36-2586-4eb3-8c91-0aac5c25e609")
+    # print(ip)
     # server_ip = cloudpods.get_server_ip("e3b76ec7-c4f9-4065-8ce2-9d833b51368c")
     # print(server_ip)
     # cloudpods = CloudPods('https://10.240.30.110:30500/v3', 'admin', 'jSj@2008')
